// tslint:disable
import { Component, ViewChild } from "@angular/core";

import * as wjcCore from "@grapecity/wijmo";
import * as wjcGrid from "@grapecity/wijmo.grid";
import * as wjcGridDetail from "@grapecity/wijmo.grid.detail";
import * as wjcGridFilter from "@grapecity/wijmo.grid.filter";
import * as wjcGridPdf from "@grapecity/wijmo.grid.pdf";
import * as wjcPdf from "@grapecity/wijmo.pdf";
import * as wjcOdata from "@grapecity/wijmo.odata";

const url = "https://services.odata.org/Northwind/Northwind.svc";

@Component({
  selector: "app-root",
  templateUrl: "./app.component.html",
  styleUrls: ["./app.component.css"]
})
export class AppComponent {
  source: any;
  @ViewChild("grid", { static: true }) grid: wjcGrid.FlexGrid;
  @ViewChild("filter", { static: true }) filter: wjcGridFilter.FlexGridFilter;
  categories: wjcOdata.ODataCollectionView;
  products: wjcOdata.ODataCollectionView;
  catToProductMap: Map<string, any> = new Map();

  constructor() {
    this.source = this.getData(50);
    this.categories = this._getCategories();
    this.products = this._getProducts();
  }

  private _getCategories() {
    return new wjcOdata.ODataCollectionView(url, "Categories", {
      fields: ["CategoryID", "CategoryName", "Description"]
    });
  }

  private _getProducts() {
    return new wjcOdata.ODataCollectionView(url, "Products");
  }

  getProducts(categoryID: string) {
    let categoryProducts = this.catToProductMap.get(categoryID);
    if (!categoryProducts) {
      categoryProducts = this.products.items.filter(
        product => product.CategoryID === categoryID
      );
      this.catToProductMap.set(categoryID, categoryProducts);
    }
    return categoryProducts;
  }

  onClick(e: MouseEvent) {
    const doc = new wjcPdf.PdfDocument({
      ended: function(
        s: wjcPdf.PdfDocument,
        e: wjcPdf.PdfDocumentEndedEventArgs
      ) {
        wjcPdf.saveBlob(e.blob, "Report.pdf");
      },
      header: {
        declarative: {
          text: "\tHeader\t&[Page]",
          font: new wjcPdf.PdfFont("helvetica", 20, "normal", "bold")
        }
      },
      footer: {
        declarative: {
          text: "\t&[Page]\\&[Pages]",
          brush: "#3173c0",
          font: new wjcPdf.PdfFont("helvetica", 20, "normal", "bold")
        }
      },
      pageSettings: {
        margins: {
          top: 20,
          left: 20,
          right: 20,
          bottom: 20
        }
      }
    });

    doc.setFont(new wjcPdf.PdfFont("helvetica", 10, "normal", "normal"));
    doc.moveDown();

    // draw the filter text if applied
    doc.drawText("The data is filtered according to these columns:");
    doc.moveDown();
    this.grid.columns.forEach(col => {
      if (this.filter.getColumnFilter(col).isActive) {
        doc.drawText(col.header);
        doc.moveDown();
      }
    });

    doc.moveDown();

    wjcGridPdf.FlexGridPdfConverter.draw(this.grid, doc, doc.width, null, {
      drawDetailRows: true,
      formatItem: function(args) {
        if (args.panel.cellType === wjcGrid.CellType.Cell) {
          let row = args.panel.rows[args.row];
          if (row instanceof wjcGridDetail.DetailRow) {
            let detail = wjcCore.Control.getControl(row.detail.children[0]),
              r = args.contentRect;

            if (detail) {
              wjcGridPdf.FlexGridPdfConverter.drawToPosition(
                detail,
                args.canvas.document,
                new wjcCore.Point(r.left, r.top),
                r.width,
                r.height
              );
              args.cancel = true;
            }
          }
        }
      }
    });

    doc.moveDown();
    doc.moveDown();

    // draw the signature part
    const settings: wjcPdf.IPdfTextDrawSettings = {
      font: new wjcPdf.PdfFont("helvetica", 15, "normal", "normal")
    };
    doc.drawText("Signature:", null, null, settings);
    doc.moveDown();
    doc.drawText("Name:", null, null, settings);
    doc.moveDown();
    doc.drawText("Date:", null, null, settings);

    doc.end();
  }

  getData(count: number) {
    let countries = "US,Germany,UK,Japan,Italy,Greece".split(","),
      data = [];
    for (let i = 0; i < count; i++) {
      data.push({
        id: i,
        country: countries[i % countries.length],
        date: new Date(2014, i % 12, i % 28),
        amount: Math.random() * 10000,
        active: i % 4 === 0
      });
    }
    return new wjcCore.CollectionView(data);
  }
}
